#
# Slicer3Config.cmake - Slicer3 CMake configuration file for external projects
#
# This file is configured by Slicer3 and used by UseSlicer3.cmake module
# to load Slicer3's settings for an external project. External projects
# can use these setting to build new modules against a Slicer3 build tree
# or a Slicer3 installation.
#

# Slicer could be installed anywhere, so set all paths based on where 
# this file was found (which should be the lib/Slicer3 directory of the 
# installation)
GET_FILENAME_COMPONENT(Slicer3_CONFIG_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

# The Slicer3 include file directories.
SET(Slicer3_INCLUDE_DIRS "${Slicer3_CONFIG_DIR}/../../include/Slicer3" "${Slicer3_CONFIG_DIR}/../../include/MRML")

# The Slicer3 library directories.
# ${Slicer3_CONFIG_DIR}/.. is needed for VTK and teem
SET(Slicer3_LIBRARY_DIRS "${Slicer3_CONFIG_DIR}" "${Slicer3_CONFIG_DIR}/.." "${Slicer3_CONFIG_DIR}/../MRML")

# The C and C++ flags added by Slicer3 to the cmake-configured flags.
SET(Slicer3_REQUIRED_C_FLAGS "")
SET(Slicer3_REQUIRED_CXX_FLAGS "")
SET(Slicer3_REQUIRED_LINK_FLAGS "")

# The Slicer3 version number
SET(Slicer3_VERSION_MAJOR "3")
SET(Slicer3_VERSION_MINOR "0")
SET(Slicer3_VERSION_PATCH "2008-04-02")

# The location of the UseSlicer3.cmake file.
SET(Slicer3_USE_FILE "${Slicer3_CONFIG_DIR}/UseSlicer3.cmake")

# The build settings file.
SET(Slicer3_BUILD_SETTINGS_FILE "${Slicer3_CONFIG_DIR}/Slicer3BuildSettings.cmake")

# Whether Slicer3 was built with shared libraries.
SET(Slicer3_BUILD_SHARED "ON")

# Components needed to build modules from outside a Slicer3 build tree or 
# from outside a Slicer3 installation tree
SET(TCLAP_DIR "${Slicer3_CONFIG_DIR}/../tclap")
SET(ModuleDescriptionParser_DIR "${Slicer3_CONFIG_DIR}/../ModuleDescriptionParser")
SET(GenerateCLP_DIR "${Slicer3_CONFIG_DIR}/../GenerateCLP")
SET(GenerateCLP_USE_FILE "${GenerateCLP_DIR}/UseGenerateCLP.cmake")
SET(GENERATECLP_EXE "${Slicer3_CONFIG_DIR}/../../bin/GenerateCLP")
SET(ITK_DIR "${Slicer3_CONFIG_DIR}/../InsightToolkit")
# VTK_DIR needs to be an absolute path for the VTKConfig.cmake file to work
SET(VTK_DIR "${Slicer3_CONFIG_DIR}/../vtk-5.0")
GET_FILENAME_COMPONENT(VTK_DIR ${VTK_DIR} ABSOLUTE)
